ZoomableImageCropperController class

Controller for the ZoomableImageCropper widget.

This controller manages the transformation and cropping of the image. It provides methods to set the media transformer, aspect ratio, and retrieve the cropped image bytes.

Constructors

ZoomableImageCropperController({required FileImage image, required double aspectRatio, required int imageWidth, required int imageHeight, required double containerHeight, required double containerWidth, void onInteractionUpdate(ScaleUpdateDetails)?, bool showResizeGrid = true})
Creates a new ZoomableImageCropperController instance.

Properties

aspectRatio double
getter/setter pair
containerHeight double
final
containerWidth double
final
hashCode int
The hash code for this object.
no setterinherited
image FileImage
final
imageHeight int
final
imageWidth int
final
mediaTransformer ↔ MediaTransformer
getter/setter pair
onInteractionUpdate → void Function(ScaleUpdateDetails)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showGrid$ StreamController<bool>
getter/setter pair
showResizeGrid bool
final
transformationController TransformationController
final

Methods

getCurrentCropImageBytes() Future<Uint8List>
Retrieves the bytes of the current cropped image.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAspectRatio(double aspectRatio) → dynamic
Sets the aspect ratio for cropping.
setMediaTransformer(MediaTransformer mediaTransformer) → dynamic
Sets the media transformer for the controller.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited